# Roadmap Report
### On this page
  * [HOW is it useful?](https://help.sap.com/docs/leanix/ea/roadmap-report#how-is-it-useful?)
  * [Using the Roadmap Reports](https://help.sap.com/docs/leanix/ea/roadmap-report#using-the-roadmap-reports)
  * [Applying Filter](https://help.sap.com/docs/leanix/ea/roadmap-report#applying-filter)
  * [Editing in the Report](https://help.sap.com/docs/leanix/ea/roadmap-report#editing-in-the-report)
  * [Clustering in Roadmap Report](https://help.sap.com/docs/leanix/ea/roadmap-report#clustering-in-roadmap-report)
  * [Clear Overview of Successor](https://help.sap.com/docs/leanix/ea/roadmap-report#clear-overview-of-successor)
  * [Hide Applications Outside the Defined Timeline](https://help.sap.com/docs/leanix/ea/roadmap-report#hide-applications-outside-the-defined-timeline)


The Roadmap Report is a visual representation of the future direction of an organization's enterprise architecture. It outlines the strategic initiatives, projects, and priorities that the organization plans to undertake to achieve its desired future state.
Roadmap Reports give a timeline view of Applications, IT Components, or Projects and allow users to visualize their organization’s IT strategy and evolution of IT portfolio over time. Different views can be applied, e.g., Functional Fit, Lifecycle, Business Criticality, etc. to see the portfolio of assets across time in different dimensions.
**Note**
Roadmap Report is configurable and can be set to any of the Fact Sheet types present in the workspace data model. This documentation shows examples from the Application and Project Roadmap Report.
The Roadmap Report is an important tool for organizations to align their IT investments and resources with their business objectives. It enables them to communicate their vision and plans to stakeholders across the organization, including IT leaders, business executives, and other stakeholders. Building a roadmap is typically the final step when running use cases like [Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases.") or [Application Rationalization](https://help.sap.com/docs/leanix/ea/application-rationalization?locale=en-US&state=PRODUCTION&version=CLOUD "Application rationalization reduces costs, eliminates redundancies, and improves efficiency. Optimize your application landscape with this step-by-step approach.").
![View of the Application Roadmap Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275159577a441014816c9d8338a9426c_LowRes.png)
View of the Application Roadmap Report
